@@ -95,7 +95,7 @@ namespace Gecode {
       throw TooFewArguments("Int::min");
     GECODE_POST;
     ViewArray<MinusView> m(home,x.size());
-    for (int i=x.size(); i--; )
+    for (int i=0; i<x.size(); i++)
       m[i] = MinusView(x[i]);
     MinusView my(y);
     if (vbd(ipl) == IPL_DOM) {
@@ -112,7 +112,7 @@ namespace Gecode {
     using namespace Int;
     if (x.size() == 0)
       throw TooFewArguments("Int::argmax");
-    if (x.same(y))
+    if (same(x,y))
       throw ArgumentSame("Int::argmax");
     GECODE_POST;
     // Constrain y properly
@@ -121,7 +121,7 @@ namespace Gecode {
     GECODE_ME_FAIL(yv.le(home,x.size()));
     // Construct index view array
     IdxViewArray<IntView> ix(home,x.size());
-    for (int i=x.size(); i--; ) {
+    for (int i=0; i<x.size(); i++) {
       ix[i].idx=i; ix[i].view=x[i];
     }
     if (tiebreak)
@@ -139,7 +139,7 @@ namespace Gecode {
     Limits::nonnegative(o,"Int::argmax");
     if (x.size() == 0)
       throw TooFewArguments("Int::argmax");
-    if (x.same(y))
+    if (same(x,y))
       throw ArgumentSame("Int::argmax");
     GECODE_POST;
     // Constrain y properly
@@ -148,7 +148,7 @@ namespace Gecode {
     GECODE_ME_FAIL(yv.le(home,x.size()));
     // Construct index view array
     IdxViewArray<IntView> ix(home,x.size());
-    for (int i=x.size(); i--; ) {
+    for (int i=0; i<x.size(); i++) {
       ix[i].idx=i; ix[i].view=x[i];
     }
     if (tiebreak)
@@ -165,7 +165,7 @@ namespace Gecode {
     using namespace Int;
     if (x.size() == 0)
       throw TooFewArguments("Int::argmin");
-    if (x.same(y))
+    if (same(x,y))
       throw ArgumentSame("Int::argmin");
     GECODE_POST;
     // Constrain y properly
@@ -174,7 +174,7 @@ namespace Gecode {
     GECODE_ME_FAIL(yv.le(home,x.size()));
     // Construct index view array
     IdxViewArray<MinusView> ix(home,x.size());
-    for (int i=x.size(); i--; ) {
+    for (int i=0; i<x.size(); i++) {
       ix[i].idx=i; ix[i].view=MinusView(x[i]);
     }
     if (tiebreak)
@@ -192,7 +192,7 @@ namespace Gecode {
     Limits::nonnegative(o,"Int::argmin");
     if (x.size() == 0)
       throw TooFewArguments("Int::argmin");
-    if (x.same(y))
+    if (same(x,y))
       throw ArgumentSame("Int::argmin");
     GECODE_POST;
     // Constrain y properly
@@ -201,7 +201,7 @@ namespace Gecode {
     GECODE_ME_FAIL(yv.le(home,x.size()));
     // Construct index view array
     IdxViewArray<MinusView> ix(home,x.size());
-    for (int i=x.size(); i--; ) {
+    for (int i=0; i<x.size(); i++) {
       ix[i].idx=i; ix[i].view=MinusView(x[i]);
     }
     if (tiebreak)
