@@ -69,19 +69,19 @@ namespace Gecode { namespace Int { namespace BinPacking {
 
 
   forceinline bool
-  same(const Item& i, const Item& j) {
-    return same(i.bin(),j.bin()) && (i.size() == j.size());
+  operator ==(const Item& i, const Item& j) {
+    return (i.bin() == j.bin()) && (i.size() == j.size());
   }
   forceinline bool
-  before(const Item& i, const Item& j) {
-    return before(i.bin(),j.bin())
-      || (same(i.bin(),j.bin()) && (i.size() == j.size()));
+  operator !=(const Item& i, const Item& j) {
+    return !(i == j);
   }
 
   /// For sorting according to size
   forceinline bool
   operator <(const Item& i, const Item& j) {
-    return i.size() > j.size();
+    return ((i.size() > j.size()) ||
+            ((i.size() == j.size()) && (i.bin() < j.bin())));
   }
 
 
@@ -152,7 +152,7 @@ namespace Gecode { namespace Int { namespace BinPacking {
     : Propagator(home), l(l0), bs(bs0), t(0) {
     l.subscribe(home,*this,PC_INT_BND);
     bs.subscribe(home,*this,PC_INT_DOM);
-    for (int i=bs.size(); i--; )
+    for (int i=0; i<bs.size(); i++)
       t += bs[i].size();
   }
 
