@@ -54,7 +54,8 @@ namespace Gecode {
   public:
     /// Initialize \a s with iterator \a i
     static void init(IntSet& s, I& i) {
-      Support::DynamicArray<IntSet::Range,Heap> d(heap);
+      Region reg;
+      Support::DynamicArray<IntSet::Range,Region> d(reg);
       int n=0;
       unsigned int size = 0;
       while (i()) {
@@ -63,7 +64,7 @@ namespace Gecode {
       }
       if (n > 0) {
         IntSet::IntSetObject* o = IntSet::IntSetObject::allocate(n);
-        for (int j=n; j--; )
+        for (int j=0; j<n; j++)
           o->r[j]=d[j];
         o->size = size;
         s.object(o);
@@ -94,12 +95,49 @@ namespace Gecode {
 
   forceinline
   IntSet::IntSet(const int r[][2], int n) {
-    init(r,n);
+    if (n > 0)
+      init(r,n);
   }
 
   forceinline
   IntSet::IntSet(const int r[], int n) {
-    init(r,n);
+    if (n > 0)
+      init(r,n);
+  }
+
+  /// Initialize with integers from vector \a r
+  template<>
+  inline
+  IntSet::IntSet(const std::vector<int>& r) {
+    int n = static_cast<int>(r.size());
+    if (n > 0) {
+      Region reg;
+      Range* dr = reg.alloc<Range>(n);
+      for (int i=0; i<n; i++)
+        dr[i].min=dr[i].max=r[i];
+      normalize(&dr[0],n);
+    }
+  }
+
+  /** \brief Initialize with ranges from vector \a r
+   *
+   * The minimum is the first element and the maximum is the
+   * second element.
+   */
+  template<>
+  inline
+  IntSet::IntSet(const std::vector<std::pair<int,int>>& r) {
+    int n = static_cast<int>(r.size());
+    if (n > 0) {
+      Region reg;
+      Range* dr = reg.alloc<Range>(n);
+      int j=0;
+      for (int i=0; i<n; i++) 
+        if (r[i].first <= r[i].second) {
+          dr[j].min=r[i].first; dr[j].max=r[i].second; j++;
+        }
+      normalize(&dr[0],j);
+    }
   }
 
   forceinline
@@ -156,12 +194,31 @@ namespace Gecode {
   forceinline unsigned int
   IntSet::size(void) const {
     IntSetObject* o = static_cast<IntSetObject*>(object());
-    return (o == NULL) ? 0 : o->size;
+    return (o == NULL) ? 0U : o->size;
   }
 
   forceinline unsigned int
   IntSet::width(void) const {
-    return static_cast<unsigned int>(max()-min()+1);
+    IntSetObject* o = static_cast<IntSetObject*>(object());
+    return (o == NULL) ? 0U : static_cast<unsigned int>(max()-min()+1);
+  }
+
+  forceinline bool
+  IntSet::operator ==(const IntSet& s) const {
+    IntSetObject* o1 = static_cast<IntSetObject*>(object());
+    IntSetObject* o2 = static_cast<IntSetObject*>(s.object());
+    if (o1 == o2)
+      return true;
+    if ((o1 == nullptr) || (o2 == nullptr))
+      return false;
+    if ((o1->size != o2->size) || (o1->n != o2->n))
+      return false;
+    return o1->equal(*o2);
+  }
+
+  forceinline bool
+  IntSet::operator !=(const IntSet& s) const {
+    return !(*this == s);
   }
 
 
