@@ -41,7 +41,7 @@ namespace Gecode { namespace Int { namespace Linear {
   estimate(Term<View>* t, int n, int c, int& l, int &u) {
     long long int min = c;
     long long int max = c;
-    for (int i=n; i--; ) {
+    for (int i=0; i<n; i++) {
       long long int a = t[i].a;
       if (a > 0) {
         min += a*t[i].x.min();
@@ -69,7 +69,7 @@ namespace Gecode { namespace Int { namespace Linear {
   public:
     forceinline bool
     operator ()(const Term<View>& a, const Term<View>& b) {
-      return before(a.x,b.x);
+      return a.x < b.x;
     }
   };
 
@@ -132,7 +132,7 @@ namespace Gecode { namespace Int { namespace Linear {
         Limits::check(t[i].a,"Int::linear");
         long long int a = t[i].a;
         View x = t[i].x;
-        while ((++i < n) && same(t[i].x,x)) {
+        while ((++i < n) && (t[i].x == x)) {
           a += t[i].a;
           Limits::check(a,"Int::linear");
         }
@@ -167,7 +167,7 @@ namespace Gecode { namespace Int { namespace Linear {
      * Make all coefficients positive
      *
      */
-    for (int i=n_n; i--; )
+    for (int i=0; i<n_n; i++)
       t_n[i].a = -t_n[i].a;
 
     /*
@@ -189,7 +189,7 @@ namespace Gecode { namespace Int { namespace Linear {
      * Test for unit coefficients only
      *
      */
-    for (int i=n; i--; )
+    for (int i=0; i<n; i++)
       if (t[i].a != 1)
         return false;
     return true;
