@@ -47,7 +47,7 @@ namespace Gecode { namespace Int { namespace Unshare {
   public:
     forceinline bool
     operator ()(const Var* a, const Var* b) {
-      return a->before(*b);
+      return a->varimp() < b->varimp();
     }
   };
   
@@ -112,7 +112,7 @@ namespace Gecode { namespace Int { namespace Unshare {
     
     Region r;
     Var** y = r.alloc<Var*>(n);
-    for (int i=n; i--; )
+    for (int i=0; i<n; i++)
       y[i]=&x[i];
 
     VarPtrLess<Var> vpl;
@@ -121,7 +121,7 @@ namespace Gecode { namespace Int { namespace Unshare {
     // Replace all shared variables with new and equal variables
     for (int i=0; i<n;) {
       int j=i++;
-      while ((i<n) && y[j]->same(*y[i]))
+      while ((i<n) && (y[j]->varimp() == y[i]->varimp()))
         i++;
       if (!y[j]->assigned())
         link(home,&y[j],i-j,ipl);
