@@ -422,6 +422,15 @@ namespace Gecode { namespace Int {
   std::basic_ostream<Char,Traits>&
   operator <<(std::basic_ostream<Char,Traits>& os, const MinusView& x);
 
+  /** \name View comparison
+   *  \relates Gecode::Int::MinusView
+   */
+  //@{
+  /// Test whether views \a x and \a y are the same
+  bool operator ==(const MinusView& x, const MinusView& y);
+  /// Test whether views \a x and \a y are not the same
+  bool operator !=(const MinusView& x, const MinusView& y);
+  //@}
 
   /**
    * \brief Offset integer view
@@ -576,6 +585,12 @@ namespace Gecode { namespace Int {
     /// Update this view to be a clone of view \a y
     void update(Space& home, OffsetView& y);
     //@}
+
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const OffsetView& y) const;
+    //@}
   };
 
   /**
@@ -591,9 +606,9 @@ namespace Gecode { namespace Int {
    */
   //@{
   /// Test whether views \a x and \a y are the same
-  bool same(const OffsetView& x, const OffsetView& y);
-  /// Test whether view \a x comes before \a y (arbitrary order)
-  bool before(const OffsetView& x, const OffsetView& y);
+  bool operator ==(const OffsetView& x, const OffsetView& y);
+  /// Test whether views \a x and \a y are not the same
+  bool operator !=(const OffsetView& x, const OffsetView& y);
   //@}
 
   /**
@@ -774,6 +789,12 @@ namespace Gecode { namespace Int {
     /// Update this view to be a clone of view \a y
     void update(Space& home, ScaleView<Val,UnsVal>& y);
     //@}
+
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const ScaleView<Val,UnsVal>& y) const;
+    //@}
   };
 
   /**
@@ -810,10 +831,12 @@ namespace Gecode { namespace Int {
   //@{
   /// Test whether views \a x and \a y are the same
   template<class Val, class UnsVal>
-  bool same(const ScaleView<Val,UnsVal>& x, const ScaleView<Val,UnsVal>& y);
-  /// Test whether view \a x comes before \a y (arbitrary order)
+  bool operator ==(const ScaleView<Val,UnsVal>& x,
+                   const ScaleView<Val,UnsVal>& y);
+  /// Test whether views \a x and \a y are not the same
   template<class Val, class UnsVal>
-  bool before(const ScaleView<Val,UnsVal>& x, const ScaleView<Val,UnsVal>& y);
+  bool operator !=(const ScaleView<Val,UnsVal>& x,
+                   const ScaleView<Val,UnsVal>& y);
   //@}
 
 
@@ -953,6 +976,12 @@ namespace Gecode { namespace Int {
     /// Update this view to be a clone of view \a y
     void update(Space& home, ConstIntView& y);
     //@}
+
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const ConstIntView& y) const;
+    //@}
   };
 
   /**
@@ -969,9 +998,9 @@ namespace Gecode { namespace Int {
    */
   //@{
   /// Test whether views \a x and \a y are the same
-  bool same(const ConstIntView& x, const ConstIntView& y);
-  /// Test whether view \a x is before \a y (arbitrary order)
-  bool before(const ConstIntView& x, const ConstIntView& y);
+  bool operator ==(const ConstIntView& x, const ConstIntView& y);
+  /// Test whether views \a x and \a y are not the same
+  bool operator !=(const ConstIntView& x, const ConstIntView& y);
   //@}
 
 
@@ -1116,7 +1145,9 @@ namespace Gecode { namespace Int {
    */
   //@{
   /// Test whether views \a x and \a y are the same
-  bool same(const ZeroIntView& x, const ZeroIntView& y);
+  bool operator ==(const ZeroIntView& x, const ZeroIntView& y);
+  /// Test whether views \a x and \a y are the same
+  bool operator !=(const ZeroIntView& x, const ZeroIntView& y);
   //@}
 
   template<class View> class ViewDiffRanges;
@@ -1291,7 +1322,7 @@ namespace Gecode { namespace Int {
   };
 
   /**
-   * \brief Print integer offset view
+   * \brief Print integer cached view
    * \relates Gecode::Int::CachedView
    */
   template<class Char, class Traits, class View>
@@ -1304,10 +1335,10 @@ namespace Gecode { namespace Int {
   //@{
   /// Test whether views \a x and \a y are the same
   template<class View>
-  bool same(const CachedView<View>& x, const CachedView<View>& y);
-  /// Test whether view \a x comes before \a y (arbitrary order)
+  bool operator ==(const CachedView<View>& x, const CachedView<View>& y);
+  /// Test whether views \a x and \a y are not the same
   template<class View>
-  bool before(const CachedView<View>& x, const CachedView<View>& y);
+  bool operator !=(const CachedView<View>& x, const CachedView<View>& y);
   //@}
 
   /**
@@ -1619,6 +1650,16 @@ namespace Gecode { namespace Int {
     //@}
   };
 
+  /** \name View comparison
+   *  \relates Gecode::Int::NegBoolView
+   */
+  //@{
+  /// Test whether views \a x and \a y are the same
+  bool operator ==(const NegBoolView& x, const NegBoolView& y);
+  /// Test whether views \a x and \a y are not the same
+  bool operator !=(const NegBoolView& x, const NegBoolView& y);
+  //@}
+
   /**
    * \brief Print negated Boolean view
    * \relates Gecode::Int::NegBoolView
