@@ -151,6 +151,19 @@ namespace Gecode { namespace Int {
     return BoolView::zero(d);
   }
 
+  /*
+   * View comparison
+   *
+   */
+  forceinline bool
+  operator ==(const NegBoolView& x, const NegBoolView& y) {
+    return x.base() == y.base();
+  }
+  forceinline bool
+  operator !=(const NegBoolView& x, const NegBoolView& y) {
+    return !(x == y);
+  }
+
 
   /**
    * \brief %Range iterator for negated Boolean variable views
