@@ -336,8 +336,8 @@ namespace Gecode { namespace Kernel {
   MemoryManager::MemoryManager(SharedMemory& sm)
     : cur_hcsz(MemoryConfig::hcsz_min), requested(0), slack(NULL) {
     alloc_fill(sm,cur_hcsz,true);
-    for (size_t i = MemoryConfig::fl_size_max-MemoryConfig::fl_size_min+1;
-         i--; )
+    for (size_t i = 0; i<MemoryConfig::fl_size_max-MemoryConfig::fl_size_min+1;
+         i++)
       fl[i] = NULL;
   }
 
@@ -354,8 +354,8 @@ namespace Gecode { namespace Kernel {
     // Skip the memory area at the beginning for subscriptions
     lsz   -= s_sub;
     start += s_sub;
-    for (size_t i = MemoryConfig::fl_size_max-MemoryConfig::fl_size_min+1;
-         i--; )
+    for (size_t i = 0; i<MemoryConfig::fl_size_max-MemoryConfig::fl_size_min+1;
+         i++)
       fl[i] = NULL;
   }
 
