@@ -115,6 +115,12 @@ namespace Gecode {
     /// Update this view to be a clone of view \a y
     void update(Space& home, ConstView& y);
     //@}
+
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const ConstView& y) const;
+    //@}
   };
 
 
@@ -207,19 +213,13 @@ namespace Gecode {
     /// Update this view to be a clone of view \a y
     void update(Space& home, VarImpView<Var>& y);
     //@}
-  };
 
-  /** \name View comparison
-   *  \relates VarImpView
-   */
-  //@{
-  /// Test whether views \a x and \a y are the same
-  template<class VarA, class VarB>
-  bool same(const VarImpView<VarA>& x, const VarImpView<VarB>& y);
-  /// Test whether view \a x comes before \a y (arbitrary order)
-  template<class ViewA, class ViewB>
-  bool before(const ViewA& x, const ViewB& y);
-  //@}
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const VarImpView& y) const;
+    //@}
+  };
 
 
   /**
@@ -310,6 +310,12 @@ namespace Gecode {
     /// Update this view to be a clone of view \a y
     void update(Space& home, DerivedView<View>& y);
     //@}
+
+    /// \name Ordering
+    //@{
+    /// Whether this view comes before view \a y (arbitray order)
+    bool operator <(const DerivedView<View>& y) const;
+    //@}
   };
 
 
@@ -454,6 +460,12 @@ namespace Gecode {
   forceinline void
   ConstView<View>::update(Space&, ConstView<View>&) {
   }
+  template<class View>
+  forceinline bool
+  ConstView<View>::operator <(const ConstView<View>&) const {
+    return true;
+  }
+
 
   /*
    * Variable view: contains a pointer to a variable implementation
@@ -555,6 +567,12 @@ namespace Gecode {
   VarImpView<Var>::update(Space& home, VarImpView<Var>& y) {
     x = y.x->copy(home);
   }
+  template<class Var>
+  forceinline bool
+  VarImpView<Var>::operator <(const VarImpView<Var>& y) const {
+    return this->varimp() < y.varimp();
+  }
+
 
   /*
    * Derived view: contain the base view from which they are derived
@@ -663,6 +681,11 @@ namespace Gecode {
   DerivedView<View>::update(Space& home, DerivedView<View>& y) {
     x.update(home,y.x);
   }
+  template<class View>
+  forceinline bool
+  DerivedView<View>::operator <(const DerivedView<View>& y) const {
+    return base() < y.base();
+  }
 
 
   /*
@@ -673,55 +696,111 @@ namespace Gecode {
   /// Test whether two views are the same
   template<class ViewA, class ViewB>
   forceinline bool
-  same(const ConstView<ViewA>&, const ConstView<ViewB>&) {
+  operator ==(const ConstView<ViewA>&, const ConstView<ViewB>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class Var, class View>
   forceinline bool
-  same(const VarImpView<Var>&, const ConstView<View>&) {
+  operator ==(const ConstView<View>&, const VarImpView<Var>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class ViewA, class ViewB>
   forceinline bool
-  same(const ConstView<ViewA>&, const DerivedView<ViewB>&) {
+  operator ==(const ConstView<ViewA>&, const DerivedView<ViewB>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class Var, class View>
   forceinline bool
-  same(const VarImpView<Var>&, const DerivedView<View>&) {
+  operator ==(const VarImpView<Var>&, const ConstView<View>&) {
+    return false;
+  }
+  /// Test whether two views are the same
+  template<class Var, class View>
+  forceinline bool
+  operator ==(const VarImpView<Var>&, const DerivedView<View>&) {
+    return false;
+  }
+  /// Test whether two views are the same
+  template<class ViewX, class ViewY>
+  forceinline bool
+  operator ==(const DerivedView<ViewX>&, const ConstView<ViewY>&) {
     return false;
   }
   /// Test whether two views are the same
   template<class View, class Var>
   forceinline bool
-  same(const DerivedView<View>&, const VarImpView<Var>&) {
+  operator ==(const DerivedView<View>&, const VarImpView<Var>&) {
+    return false;
+  }
+  /// Test whether two views are not the same
+  template<class ViewX, class ViewY>
+  forceinline bool
+  operator ==(const DerivedView<ViewX>&, const DerivedView<ViewY>&) {
     return false;
   }
   /// Test whether two views are the same
-  template<class Var>
+  template<class VarX, class VarY>
   forceinline bool
-  same(const VarImpView<Var>& x, const VarImpView<Var>& y) {
+  operator ==(const VarImpView<VarX>& x, const VarImpView<VarY>& y) {
     return x.varimp() == y.varimp();
   }
-  /// Test whether two views are the same
+
+  /// Test whether two views are not the same
   template<class ViewA, class ViewB>
   forceinline bool
-  same(const DerivedView<ViewA>& x, const DerivedView<ViewB>& y) {
-    return same(x.base(),y.base());
+  operator !=(const ConstView<ViewA>&, const ConstView<ViewB>&) {
+    return true;
   }
-
-
-  /*
-   * Tests whether one view is before the other
-   *
-   */
+  /// Test whether two views are not the same
+  template<class Var, class View>
+  forceinline bool
+  operator !=(const ConstView<View>&, const VarImpView<Var>&) {
+    return true;
+  }
+  /// Test whether two views are not the same
   template<class ViewA, class ViewB>
   forceinline bool
-  before(const ViewA& x, const ViewB& y) {
-    return x.varimp() < y.varimp();
+  operator !=(const ConstView<ViewA>&, const DerivedView<ViewB>&) {
+    return true;
+  }
+  /// Test whether two views are not the same
+  template<class Var, class View>
+  forceinline bool
+  operator !=(const VarImpView<Var>&, const ConstView<View>&) {
+    return true;
+  }
+  /// Test whether two views are not the same
+  template<class Var, class View>
+  forceinline bool
+  operator !=(const VarImpView<Var>&, const DerivedView<View>&) {
+    return true;
+  }
+  /// Test whether two views are the same
+  template<class ViewX, class ViewY>
+  forceinline bool
+  operator !=(const DerivedView<ViewX>&, const ConstView<ViewY>&) {
+    return true;
+  }
+  /// Test whether two views are not the same
+  template<class View, class Var>
+  forceinline bool
+  operator !=(const DerivedView<View>&, const VarImpView<Var>&) {
+    return true;
+  }
+  /// Test whether two views are not the same
+  template<class ViewX, class ViewY>
+  forceinline bool
+  operator !=(const DerivedView<ViewX>&, const DerivedView<ViewY>&) {
+    return true;
+  }
+  /// Test whether two views are not the same
+  template<class VarX, class VarY>
+  forceinline bool
+  operator !=(const VarImpView<VarX>& x, const VarImpView<VarY>& y) {
+    return x.varimp() != y.varimp();
   }
 
 
