@@ -250,7 +250,6 @@ namespace Gecode {
         } a;
       } u;
       /// Create negation normalform
-      GECODE_MINIMODEL_EXPORT
       static NNF* nnf(Region& r, Node* n, bool neg);
       /// Post propagators for nested conjunctive and disjunctive expression
       GECODE_MINIMODEL_EXPORT
@@ -626,7 +625,6 @@ namespace Gecode {
    */
   BoolVar
   expr(Home home, const BoolExpr& e, IntPropLevel ipl) {
-    PostInfo pi(home);
     if (!home.failed())
       return e.expr(home,ipl);
     BoolVar x(home,0,1);
@@ -635,7 +633,6 @@ namespace Gecode {
 
   void
   rel(Home home, const BoolExpr& e, IntPropLevel ipl) {
-    GECODE_POST;
     if (home.failed()) return;
     e.rel(home,ipl);
   }
