@@ -251,6 +251,17 @@ namespace Test { namespace Int {
     return "NONE";
   }
 
+  inline
+  std::string
+  Test::str(bool b) {
+    std::stringstream s;
+    if (b)
+      s << "+";
+    else 
+      s << "-";
+    return s.str();
+  }
+
   inline
   std::string
   Test::str(int i) {
