@@ -128,9 +128,9 @@ namespace Test { namespace Int {
          IntSet b(1,1);
          IntSet c(2,2);
          IntSet d(0,1);
-         IntArgs ie(2, 0,2);
+         IntArgs ie({0,2});
          IntSet e(ie);
-
+         
          (void) new SequenceBoolTest("A",a,3,2,2,6);
          (void) new SequenceBoolTest("B",b,3,2,2,6);
          (void) new SequenceBoolTest("C",b,6,2,2,6);
